@@ -10,7 +10,7 @@ import idna
 
 from .quoting import _Quoter, _Unquoter
 
-__version__ = '1.2.2'
+__version__ = '1.2.6'
 
 __all__ = ('URL',)
 
@@ -151,6 +151,8 @@ class URL:
         elif type(val) is SplitResult:
             if not encoded:
                 raise ValueError("Cannot apply decoding to SplitResult")
+        elif isinstance(val, str):
+            val = urlsplit(str(val))
         else:
             raise TypeError("Constructor parameter should be str")
 
